@@ -1,5 +1,5 @@
-from tkinter import Image
-from tkinter.ttk import Progressbar
+# from tkinter import Image
+# from tkinter.ttk import Progressbar
 from tifffile import imsave
 import skimage
 from skimage.io import imread, imshow, imread_collection, concatenate_images
@@ -51,11 +51,9 @@ import tempfile
 from zipfile import ZipFile
 
 import re
-import PIL
 import h5py
 
 import napari_aphid.path as paths
-from collections import Counter
 from pandas import DataFrame
 import shutil
 import matplotlib.cm as cm
@@ -307,7 +305,6 @@ def process_function_segmentation(napari_viewer : Viewer,filename=pathlib.Path.c
     print(SEG)
 
     # ICI, ON CREE DEUX CLASSES ET ON REMPLI LES TROUS
-    from collections import Counter
     from skimage.util import img_as_ubyte
     from skimage import io
 
